@@ -27,7 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QStackedWidget>
 
 // KDE
-#include <QDebug>
+#include "gwenview_importer_debug.h"
 #include <KIO/DeleteJob>
 #include <KMessageBox>
 #include <KProtocolInfo>
@@ -58,6 +58,25 @@ public:
     DialogPage* mDialogPage;
     Importer* mImporter;
 
+    void checkForFailedUrls()
+    {
+        // First check for errors on file imports or subfolder creation
+        QList<QUrl> failedUrls = mImporter->failedUrlList();
+        QList<QUrl> failedSubFolders = mImporter->failedSubFolderList();
+        int failedUrlCount = failedUrls.count();
+        int failedSubFolderCount = failedSubFolders.count();
+        if (failedUrlCount + failedSubFolderCount > 0) {
+            QStringList files, dirs;
+            for (int i=0; i<failedUrlCount; i++) {
+                files << failedUrls[i].toString(QUrl::PreferLocalFile);
+            }
+            for (int i=0; i<failedSubFolderCount; i++) {
+                dirs << failedSubFolders[i].toString(QUrl::PreferLocalFile);
+            }
+            emit q->showErrors(files, dirs);
+        }
+    }
+
     void deleteImportedUrls()
     {
         QList<QUrl> importedUrls = mImporter->importedUrlList();
@@ -144,7 +163,7 @@ public:
     {
         KService::Ptr service = KService::serviceByDesktopName("org.kde.gwenview");
         if (!service) {
-            qCritical() << "Could not find gwenview";
+            qCCritical(GWENVIEW_IMPORTER_LOG) << "Could not find gwenview";
         } else {
             KRun::runService(*service, {mThumbnailPage->destinationUrl()}, nullptr /* window */);
         }
@@ -204,6 +223,8 @@ ImportDialog::ImportDialog()
             this, &QWidget::close);
     connect(d->mImporter, &Importer::importFinished,
             this, &ImportDialog::slotImportFinished);
+    connect(this, &ImportDialog::showErrors,
+            d->mDialogPage, &DialogPage::slotShowErrors);
 
     d->mCentralWidget->setCurrentWidget(d->mThumbnailPage);
 
@@ -254,6 +275,7 @@ void ImportDialog::startImport()
 
 void ImportDialog::slotImportFinished()
 {
+    d->checkForFailedUrls();
     d->deleteImportedUrls();
     d->showWhatNext();
 }
