@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QAbstractItemView>
 #include <QPainter>
 #include <QToolButton>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 // KDE
 #include <KIconLoader>
@@ -133,7 +133,7 @@ void TagItemDelegate::slotRemoveButtonClicked()
 {
     const QModelIndex index = focusedIndex();
     if (!index.isValid()) {
-        qWarning() << "!index.isValid()";
+        qCWarning(GWENVIEW_LIB_LOG) << "!index.isValid()";
         return;
     }
     emit removeTagRequested(index.data(TagModel::TagRole).toString());
@@ -143,7 +143,7 @@ void TagItemDelegate::slotAssignToAllButtonClicked()
 {
     const QModelIndex index = focusedIndex();
     if (!index.isValid()) {
-        qWarning() << "!index.isValid()";
+        qCWarning(GWENVIEW_LIB_LOG) << "!index.isValid()";
         return;
     }
     emit assignTagToAllRequested(index.data(TagModel::TagRole).toString());
